export function polyfill_RTCIceCandidate() {
    function get_field(candidate: string, n: number): string | null {
        return candidate ? candidate.split(' ').slice(n)[0] ?? null : null;
    }

    function polyfill(prop: string, f: (candidate: string) => any) {
        if (!RTCIceCandidate.prototype.hasOwnProperty(prop))
            Object.defineProperty(RTCIceCandidate.prototype, prop, {
                get: function () {
                    return f.apply(this, [this.candidate]);
                }
            });
    }

    polyfill('foundation', (candidate) => get_field(candidate, 0)?.split(':', 1)[1] ?? null);
    polyfill('component', (candidate) => {
        let id = get_field(candidate, 1);
        if (id == null) return id;
        switch (+id) {
            case 1:
                return 'rtp';
            case 2:
                return 'rtcp';
            default:
                return null;
        }
    });
    polyfill('protocol', (candidate) => get_field(candidate, 2)?.toLowerCase() ?? null);
    polyfill('priority', (candidate) => get_field(candidate, 3));
    polyfill('address', (candidate) => get_field(candidate, 4));
    polyfill('port', (candidate) => get_field(candidate, 5));
    polyfill('type', (candidate) => get_field(candidate, 7));
    polyfill('relatedAddress', (candidate) =>
        get_field(candidate, 8) == 'raddr' ? get_field(candidate, 9) : null
    );
    polyfill('relatedPort', (candidate) => {
        let i = get_field(candidate, 8) == 'raddr' ? 10 : 8;
        return get_field(candidate, i) == 'rport' ? get_field(candidate, i + 1) : null;
    });
    polyfill('tcpType', function (this: { protocol: string }, candidate) {
        return this.protocol === 'tcp' ? get_field(candidate, -1) : null;
    });
}